@@ -15,7 +15,6 @@ from utils import (
     wait_for_id,
 )
 
-import univention.testing.ucr as ucr_test
 from univention.testing.utils import get_ldap_connection
 
 
@@ -41,30 +40,29 @@ def test_session_sync(ucr, udm, portal_login_via_keycloak, portal_config, keyclo
     login_url = f"https://{login_host}.{ucr['domainname']}"
     check_url = f"https://{check_host}.{ucr['domainname']}"
 
-    with ucr_test.UCSTestConfigRegistry() as _ucr:
-        # set ucs-sso-ng to login ip
-        _ucr.handler_set([f"hosts/static/{login_ip}={fqdn}"])
-        assert socket.gethostbyname(fqdn) == login_ip
-        # login on login_host
-        username = udm.create_user()[1]
-        print(f"login to {login_url} ({login_ip})")
-        driver = portal_login_via_keycloak(username, "univention", url=login_url)
-        # change ucs-sso-ng to check_ip
-        _ucr.handler_unset([f"hosts/static/{login_ip}"])
-        _ucr.handler_set([f"hosts/static/{check_ip}={fqdn}"])
-        assert socket.gethostbyname(fqdn) == check_ip
-        # check portal in check_url
-        print(f"check session on {check_url} ({check_ip})")
-        driver.get(check_url)
-        wait_for_id(driver, portal_config.categories_id)
-        get_portal_tile(driver, portal_config.sso_login_tile_de, portal_config).click()
-        wait_for_id(driver, portal_config.header_menu_id).click()
-        a = wait_for_class(driver, portal_config.portal_sidenavigation_username_class)[0]
-        assert a.text == username
-        # check sessions
-        sessions = keycloak_sessions_by_user(keycloak_config, username)[0]
-        assert f"{login_url}/univention/saml/metadata" in sessions["clients"].values()
-        assert f"{check_url}/univention/saml/metadata" in sessions["clients"].values()
+    # set ucs-sso-ng to login ip
+    ucr.handler_set([f"hosts/static/{login_ip}={fqdn}"])
+    assert socket.gethostbyname(fqdn) == login_ip
+    # login on login_host
+    username = udm.create_user()[1]
+    print(f"login to {login_url} ({login_ip})")
+    driver = portal_login_via_keycloak(username, "univention", url=login_url)
+    # change ucs-sso-ng to check_ip
+    ucr.handler_unset([f"hosts/static/{login_ip}"])
+    ucr.handler_set([f"hosts/static/{check_ip}={fqdn}"])
+    assert socket.gethostbyname(fqdn) == check_ip
+    # check portal in check_url
+    print(f"check session on {check_url} ({check_ip})")
+    driver.get(check_url)
+    wait_for_id(driver, portal_config.categories_id)
+    get_portal_tile(driver, portal_config.sso_login_tile_de, portal_config).click()
+    wait_for_id(driver, portal_config.header_menu_id).click()
+    a = wait_for_class(driver, portal_config.portal_sidenavigation_username_class)[0]
+    assert a.text == username
+    # check sessions
+    sessions = keycloak_sessions_by_user(keycloak_config, username)[0]
+    assert f"{login_url}/univention/saml/metadata" in sessions["clients"].values()
+    assert f"{check_url}/univention/saml/metadata" in sessions["clients"].values()
 
 
 def test_every_umc_server_has_a_saml_client(ucr, keycloak_config):
@@ -106,6 +104,9 @@ def test_master_realm_config(keycloak_config, ucr):
 
 
 def test_ucs_realm_config(keycloak_config, ucr):
+    sso_fqdn = ucr.get('keycloak/server/sso/fqdn')
+    kerberos_realm = ucr.get('kerberos/realm')
+
     # required actions ucs realm
     required_actions = keycloak_get_request(keycloak_config, "realms/ucs/authentication/required-actions")
     required_actions = [ra["alias"] for ra in required_actions if ra["enabled"]]
@@ -117,6 +118,14 @@ def test_ucs_realm_config(keycloak_config, ucr):
     assert ldap_federation["providerId"] == "ldap"
     assert ldap_federation["config"]["enabled"] == ["true"]
     assert ldap_federation["config"]["editMode"] == ["READ_ONLY"]
+    assert ldap_federation["config"]["allowKerberosAuthentication"] == ["true"]
+    assert ldap_federation["config"]["kerberosRealm"] == [ucr.get("kerberos/realm")]
+    if sso_fqdn:
+        assert ldap_federation["config"]["serverPrincipal"] == [f"HTTP/{sso_fqdn}@{kerberos_realm}"]
+    else:
+        # not a keycloak server so sso_fqdn is not set. Check at least if it is set and the kerberos_realm is present
+        assert kerberos_realm in ldap_federation["config"]["serverPrincipal"][0]
+    assert ldap_federation["config"]["keyTab"] == ["/var/lib/univention-appcenter/apps/keycloak/conf/keycloak.keytab"]
     components = keycloak_get_request(keycloak_config, f"realms/ucs/components?parent={ldap_federation['id']}")
     components = [c["name"] for c in components]
     assert set(components) == {
@@ -141,13 +150,11 @@ def test_csp(keycloak_config, ucr):
     if ucr["server/role"] != "domaincontroller_master":
         pytest.skip("onyl on master, we have scenarios where keycloak/server/sso/fqdn points to a different server, but in this test we changed the local apache config.")
     try:
-        with ucr_test.UCSTestConfigRegistry() as _ucr:
-            # change app setting for csp
-            _ucr.handler_set(['keycloak/csp/frame-ancestors=https://*.external.com'])
-            run_command(['systemctl', 'restart', 'apache2'])
-            # test again the
-            response = requests.post(keycloak_config.admin_url, headers={"Accept": "text/html"})
-            assert response.headers["Content-Security-Policy"]
-            assert f"frame-src 'self'; frame-ancestors 'self' https://*.{ucr['domainname']} https://*.external.com;  object-src 'none';" == response.headers["Content-Security-Policy"]
+        # change app setting for csp
+        ucr.handler_set(['keycloak/csp/frame-ancestors=https://*.external.com'])
+        run_command(['systemctl', 'restart', 'apache2'])
+        response = requests.post(keycloak_config.admin_url, headers={"Accept": "text/html"})
+        assert response.headers["Content-Security-Policy"]
+        assert f"frame-src 'self'; frame-ancestors 'self' https://*.{ucr['domainname']} https://*.external.com;  object-src 'none';" == response.headers["Content-Security-Policy"]
     finally:
         run_command(['systemctl', 'restart', 'apache2'])
